@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = '0.1.47';
+our $VERSION = '0.1.48';
 
 use base 'Exporter'; 
 
@@ -16,8 +16,13 @@ sub version {
 package main;
 use strict;
 use Test::More;
+use Data::Dumper;
 
 our $HTTP_RESPONSE;
+our @CONTEXT = ();
+our @CONTEXT_C = ();
+our $BLOCK_MODE;
+ 
 our ($project);
 our ($curl_cmd, $content_file);
 our ($url, $path, $route_dir, $http_meth); 
@@ -59,6 +64,22 @@ sub make_http_request {
     return $HTTP_RESPONSE;
 }
 
+sub populate_context {
+
+    my $data = shift;
+    my $i = 0;
+
+    @CONTEXT = ();
+
+    for my $l ( split /\n/, $data ){
+        chomp $l;
+        $i++;
+        push @CONTEXT, [$l, $i];        
+    }
+    @CONTEXT_C = @CONTEXT;
+    diag("context populated") if debug_mod2();
+}
+
 sub hostname {
     my $a = `hostname`;
     chomp $a;
@@ -72,18 +93,28 @@ sub check_line {
     my $message = shift;
 
     my $status = 0;
-    my $data = make_http_request();
 
     my @chunks;
 
+    my @context_new = ();
+
+    diag("lookup $pattern ...") if debug_mod2();
     if ($check_type eq 'default'){
-        $status = 1 if index($data,$pattern) != -1
+        for my $c (@CONTEXT_C){
+            my $ln = $c->[0]; my $next_i = $c->[1];
+            if ( index($ln,$pattern) != -1){
+                $status = 1;
+                push @context_new, $CONTEXT[$next_i];
+            }
+        }
     }elsif($check_type eq 'regexp'){
-        for my $l (split /\n/, $data){
-            chomp $l; my $re = qr/$pattern/;
-            if ($l =~ $re ){
+        for my $c (@CONTEXT_C){
+            my $re = qr/$pattern/;
+            my $ln = $c->[0]; my $next_i = $c->[1];
+            if ($ln =~ $re ){
                 push @chunks, $1||$&;
                 $status = 1;
+                push @context_new, $CONTEXT[$next_i];
             }
         }
     }else {
@@ -97,6 +128,10 @@ sub check_line {
         diag("line found: $c") if debug_mod1() or debug_mod2();
     }
 
+    if ($BLOCK_MODE){
+        @CONTEXT_C = @context_new; 
+    }
+
     return
 
 }
@@ -132,6 +167,8 @@ sub generate_asserts {
 
 
 
+    populate_context( make_http_request() );
+  
     ENTRY: for my $l (@ents){
 
         chomp $l;
@@ -143,6 +180,18 @@ sub generate_asserts {
             next ENTRY;
         }
 
+        if ($l=~ /^\s*begin:\s*$/) { # begin: block marker
+            diag("begin: block") if debug_mod2();
+            $BLOCK_MODE=1;
+            next ENTRY;
+        }
+        if ($l=~ /^\s*end:\s*$/) { # end: block marker
+            $BLOCK_MODE=0;
+            populate_context( make_http_request() );
+            diag("end: block") if debug_mod2();
+            next ENTRY;
+        }
+
         if ($l=~/^\s*code:\s*(.*)/){
             die "unterminated entity found: $ents_ok[-1]" if defined($ent_type);
             my $code = $1;
@@ -472,6 +521,57 @@ Comments entries are lines started with C<#> symbol, swat will ignore comments w
     <head><title>Hello World</title></head> # and it should be proper html code
 
 
+=head3 Matching block of text
+
+Sometimes it is very helpful not match a content against a I<single strings>, but a C<block of text>, like here:
+
+
+    # this 3 string should be in an output
+    # line by line
+
+    begin:
+    this string
+    followed by that string
+    and this one followed by previous one
+
+    # you even may to use regexps here:
+    regexp: what about (me|you)
+        and finally the last one
+    
+    end: 
+
+This kind of check should be passed when running against for example this block of text:
+
+    this string - "I am OK"
+    sure, followed by that string
+    and this one followed by previous one
+
+    what about me?
+    and finally the last one
+
+
+But B<won't> be passed against this block of text:
+
+    this string - "I am OK"
+    sure, followed by that string
+    and this one followed by previous one
+
+    what about me?
+    what about you?
+    and finally the last one
+
+C<begin:> C<end:> markes decorate block of text should present in a response content, there should not be any text after
+C<begin:|end:> marker. Also be aware if you leave "dangling" begin: marker without closing end: somewhere else this will
+implies block-of-text mode till the end of your test, which is probably not you want:
+
+
+    begin:
+    here we begin
+    and till the very end of test
+    we are in `block-of-text` mode    
+
+
+
 =head3 Perl Expressions
 
 Perl expressions are just a pieces of perl code to I<get evaled> by swat when parsing test data files.
